@@ -138,6 +138,11 @@ mediaShow.loadSlide = function (slideshow, slideNumber)
         
         slide.loaded = mediaShow.LOADED;
         
+        //if( $('body.template-folder_slideshow_view').length > 0 )
+        //{
+        //    slideshow.obj.prepend($('<a name="'+slide.UID+'"></a>'));
+        //}
+        
         $(slideContainer).touchwipe({
             wipeLeft: function() {mediaShow.prev(mediaShow.indexOf(slideshow)) },
             wipeRight: function() { mediaShow.next(mediaShow.indexOf(slideshow)) },
@@ -247,5 +252,6 @@ mediaShow.reAlign = function ()
 //Adding custom text to the buttons
 $(function(){
     $('.buttonPrev').text("Vorige");
-    $('.buttonNext').text("Volgende");    
+    $('.buttonNext').text("Volgende");
+    $('.portlet-static-2018eenmaal-andermaal-documentatie .portletHeader span').wrap('<a href="http://www.porseleinplaats.nl/algemeen/eenmaal-andermaal-doc/eenmaal-andermaal-doc/"></a>');
 });
\ No newline at end of file
